Struct

EBookContactsContactDateTime

Description

struct EContactDateTime {
  gushort year;
  gushort month;
  gushort day;
  gushort hour;
  gushort minute;
  gushort second;
  gint utc_offset;
}

No description available.

Structure members
year: gushort

No description available.

month: gushort

No description available.

day: gushort

No description available.

hour: gushort

No description available.

minute: gushort

No description available.

second: gushort

No description available.

utc_offset: gint

No description available.

Constructors

e_contact_date_time_new

Creates a new EContactDateTime struct with unset date and time.

unstable since: 3.60

Functions

e_contact_date_time_from_string

Creates a new EContactDateTime based on str.

unstable since: 3.60

Instance methods

e_contact_date_time_equal

Checks if dt1 and dt2 are the same date time.

unstable since: 3.60

e_contact_date_time_free

Frees the self struct and its content.

unstable since: 3.60

e_contact_date_time_has_date

Checks whether the self has set at least one of the date members.

unstable since: 3.60

e_contact_date_time_has_time

Checks whether the self has set at least one of the time members.

unstable since: 3.60

e_contact_date_time_to_string

Generates a date/time string in the for_version format used by vCard standard, omitting unset values of the self. Free the returned string with g_free(), when no longer needed.

unstable since: 3.60